"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AiChatView = void 0;
const tslib_1 = require("tslib");
const mobx_react_lite_1 = require("mobx-react-lite");
const React = tslib_1.__importStar(require("react"));
const react_chat_elements_1 = require("react-chat-elements");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const command_1 = require("@opensumi/ide-core-browser/lib/ai-native/command");
const components_1 = require("@opensumi/ide-core-browser/lib/components");
const ai_native_1 = require("@opensumi/ide-core-browser/lib/components/ai-native");
const command_opener_1 = require("@opensumi/ide-core-browser/lib/opener/command-opener");
const ide_core_common_1 = require("@opensumi/ide-core-common");
const ide_core_common_2 = require("@opensumi/ide-core-common");
const reporter_1 = require("@opensumi/ide-core-common/lib/ai-native/reporter");
const common_1 = require("../common");
const styles = tslib_1.__importStar(require("./ai-chat.module.less"));
const ai_chat_service_1 = require("./ai-chat.service");
const generate_service_1 = require("./ai-project/generate.service");
const sumi_service_1 = require("./ai-sumi/sumi.service");
const ChatEditor_1 = require("./components/ChatEditor");
const ChatInput_1 = require("./components/ChatInput");
const ChatMarkdown_1 = require("./components/ChatMarkdown");
const ChatMoreActions_1 = require("./components/ChatMoreActions");
const ChatReply_1 = require("./components/ChatReply");
const Markdown_1 = require("./components/Markdown");
const StreamMsg_1 = require("./components/StreamMsg");
const Thinking_1 = require("./components/Thinking");
const msg_stream_manager_1 = require("./model/msg-stream-manager");
// import { AiMenubarService } from './override/layout/menu-bar/menu-bar.service';
const run_service_1 = require("./run/run.service");
const types_1 = require("./types");
require("react-chat-elements/dist/main.css");
const createMessage = (message) => (Object.assign(Object.assign({}, message), { type: 'text', className: `${message.position === 'left' ? 'rce-ai-msg' : 'rce-user-msg'} ${message.className ? message.className : ''}` }));
const createMessageByAI = (message, className) => createMessage(Object.assign(Object.assign({}, message), { position: 'left', title: '', className, role: 'ai' }));
const extractIcon = (question) => {
    let { title } = question;
    const { message, tooltip } = question;
    if (!title) {
        return {
            icon: '',
            title: message,
            message,
            tooltip,
        };
    }
    let icon;
    const iconMatched = title.match(/^\$\(([a-z.]+\/)?([a-z0-9-]+)(~[a-z]+)?\)/i);
    if (iconMatched) {
        const [matchedStr, owner, name, modifier] = iconMatched;
        const iconOwner = owner ? owner.slice(0, -1) : ide_core_browser_1.CODICON_OWNER;
        icon = (0, ide_core_browser_1.getExternalIcon)(name, iconOwner);
        if (modifier) {
            icon += ` ${modifier.slice(1)}`;
        }
        title = title.slice(matchedStr.length);
    }
    return {
        icon,
        title,
        message,
        tooltip,
    };
};
const AI_NAME = 'AI 研发助手';
const SCROLL_CLASSNAME = 'chat_scroll';
const ME_NAME = '';
const defaultSampleQuestions = [
    {
        icon: (0, ide_core_browser_1.getIcon)('send2'),
        title: '生成 Java 快速排序算法',
        message: '生成 Java 快速排序算法',
    },
];
const InitMsgComponent = () => {
    var _a, _b;
    const aiChatService = (0, ide_core_browser_1.useInjectable)(ai_chat_service_1.AiChatService);
    const chatAgentService = (0, ide_core_browser_1.useInjectable)(common_1.IChatAgentService);
    const chatFeatureRegistry = (0, ide_core_browser_1.useInjectable)(types_1.ChatFeatureRegistryToken);
    const [sampleQuestions, setSampleQuestions] = React.useState(defaultSampleQuestions);
    const welcomeSampleQuestions = React.useMemo(() => {
        if (!chatFeatureRegistry.chatWelcomeMessageModel) {
            return [];
        }
        const { sampleQuestions = [] } = chatFeatureRegistry.chatWelcomeMessageModel;
        return sampleQuestions.map(extractIcon);
    }, [(_a = chatFeatureRegistry.chatWelcomeMessageModel) === null || _a === void 0 ? void 0 : _a.sampleQuestions]);
    const welcomeMessage = React.useMemo(() => {
        const defaultWelcomeMessage = (React.createElement(React.Fragment, null,
            React.createElement("div", { className: styles.chat_container_des },
                React.createElement("img", { src: 'https://mdn.alipayobjects.com/huamei_htww6h/afts/img/A*66fhSKqpB8EAAAAAAAAAAAAADhl8AQ/original' }),
                "\u55E8\uFF0C\u6211\u662F\u60A8\u7684\u4E13\u5C5E AI \u5C0F\u52A9\u624B\uFF0C\u6211\u5728\u8FD9\u91CC\u56DE\u7B54\u6709\u5173\u4EE3\u7801\u7684\u95EE\u9898\uFF0C\u5E76\u5E2E\u52A9\u60A8\u601D\u8003\uFF01"),
            React.createElement("div", { className: styles.chat_container_title }, "\u60A8\u53EF\u4EE5\u63D0\u95EE\u6211\u4E00\u4E9B\u5173\u4E8E\u4EE3\u7801\u7684\u95EE\u9898")));
        if (!chatFeatureRegistry.chatWelcomeMessageModel) {
            return defaultWelcomeMessage;
        }
        const { content } = chatFeatureRegistry.chatWelcomeMessageModel;
        return content !== null && content !== void 0 ? content : defaultWelcomeMessage;
    }, [(_b = chatFeatureRegistry.chatWelcomeMessageModel) === null || _b === void 0 ? void 0 : _b.content]);
    React.useEffect(() => {
        const disposer = chatAgentService.onDidChangeAgents(async () => {
            const sampleQuestions = await chatAgentService.getAllSampleQuestions();
            const lists = sampleQuestions.map(extractIcon);
            // 每次全量更新数据，避免扩展卸载的问题
            setSampleQuestions([...defaultSampleQuestions, ...lists]);
        });
        return () => disposer.dispose();
    }, []);
    if (!welcomeMessage) {
        return (React.createElement(Thinking_1.Thinking, { status: 1 /* EMsgStreamStatus.THINKING */, showStop: false, thinkingText: (0, ide_core_common_2.localize)('aiNative.chat.welcome.loading.text') }));
    }
    return (React.createElement("div", { className: styles.chat_head },
        welcomeMessage,
        React.createElement("div", { className: styles.chat_container_content }, welcomeSampleQuestions.concat(sampleQuestions).map((data, index) => {
            const node = (React.createElement("a", { href: 'javascript:void(0)', className: styles.link_item, onClick: () => {
                    aiChatService.launchChatMessage(chatAgentService.parseMessage(data.message));
                } },
                data.icon ? React.createElement(components_1.Icon, { className: data.icon, style: { color: 'inherit', marginRight: '4px' } }) : '',
                React.createElement("span", null, data.title)));
            return data.tooltip ? (React.createElement(components_1.Tooltip, { title: data.tooltip, key: index }, node)) : (React.createElement(React.Fragment, { key: index }, node));
        }))));
};
exports.AiChatView = (0, mobx_react_lite_1.observer)(() => {
    const aiChatService = (0, ide_core_browser_1.useInjectable)(ai_chat_service_1.AiChatService);
    const aiProjectGenerateService = (0, ide_core_browser_1.useInjectable)(generate_service_1.AiProjectGenerateService);
    const aiSumiService = (0, ide_core_browser_1.useInjectable)(sumi_service_1.AiSumiService);
    const aiRunService = (0, ide_core_browser_1.useInjectable)(run_service_1.AiRunService);
    // const aiMenubarService = useInjectable<AiMenubarService>(AiMenubarService);
    const aiReporter = (0, ide_core_browser_1.useInjectable)(reporter_1.IAIReporter);
    const opener = (0, ide_core_browser_1.useInjectable)(command_opener_1.CommandOpener);
    const msgStreamManager = (0, ide_core_browser_1.useInjectable)(msg_stream_manager_1.MsgStreamManager);
    const chatAgentService = (0, ide_core_browser_1.useInjectable)(common_1.IChatAgentService);
    const containerRef = React.useRef(null);
    const [messageListData, setMessageListData] = React.useState([]);
    const [loading, setLoading] = React.useState(false);
    const [loading2, setLoading2] = React.useState(false);
    const commandService = (0, ide_core_browser_1.useInjectable)(ide_core_common_2.CommandService);
    // TODO: theme 基于 command 改造成 command 形式
    const [agentId, setAgentId] = React.useState('');
    const [defaultAgentId, setDefaultAgentId] = React.useState('');
    const [command, setCommand] = React.useState('');
    const [theme, setTheme] = React.useState(null);
    const [state, updateState] = React.useState();
    const chatInputRef = React.useRef(null);
    React.useEffect(() => {
        msgStreamManager.onMsgStatus((event) => {
            if (event === 2 /* EMsgStreamStatus.DONE */ || event === 3 /* EMsgStreamStatus.ERROR */) {
                setLoading2(false);
            }
            else if (event === 1 /* EMsgStreamStatus.THINKING */) {
                setLoading2(true);
            }
        });
        return () => {
            msgStreamManager.dispose();
        };
    }, []);
    // 项目生成
    const generateProject = React.useCallback(async () => {
        aiProjectGenerateService.start((messageList) => {
            const aiMessageList = messageList
                .map(({ message, immediately, type = 'message', relationId }) => type === 'message'
                ? createMessageByAI({ text: React.createElement(AiReply, { text: message, immediately: immediately }), id: (0, ide_core_common_1.uuid)(6), relationId })
                : AICodeReply(message, aiChatService, relationId))
                .filter((m) => !!m);
            setMessageListData([...aiMessageList]);
        });
    }, []);
    React.useEffect(() => {
        if (aiProjectGenerateService.requirements) {
            generateProject();
        }
    }, [aiProjectGenerateService.requirements]);
    const firstMsg = React.useMemo(() => createMessageByAI({
        id: (0, ide_core_common_1.uuid)(6),
        relationId: '',
        text: React.createElement(InitMsgComponent, null),
    }), []);
    const scrollToBottom = React.useCallback(() => {
        if (containerRef && containerRef.current) {
            containerRef.current.scrollTop = Number.MAX_SAFE_INTEGER;
            // 出现滚动条时出现分割线
            if (containerRef.current.scrollHeight > containerRef.current.clientHeight) {
                containerRef.current.classList.add(SCROLL_CLASSNAME);
            }
        }
    }, [containerRef]);
    React.useEffect(() => {
        setMessageListData([firstMsg]);
    }, []);
    React.useEffect(() => {
        scrollToBottom();
    }, [loading, loading2, state]);
    React.useEffect(() => {
        const dispose = msgStreamManager.onMsgStatus(() => {
            requestAnimationFrame(() => {
                scrollToBottom();
            });
        });
        return () => dispose.dispose();
    }, [msgStreamManager.onMsgStatus]);
    React.useEffect(() => {
        const dispose = aiChatService.onChatMessageLaunch(async (message) => {
            var _a;
            if (message.immediate !== false) {
                if (loading) {
                    return;
                }
                await handleSend(message);
            }
            else {
                if (message.agentId) {
                    setAgentId(message.agentId);
                }
                if (message.command) {
                    setCommand(message.command);
                }
                (_a = chatInputRef === null || chatInputRef === void 0 ? void 0 : chatInputRef.current) === null || _a === void 0 ? void 0 : _a.setInputValue(message.message);
            }
        });
        return () => dispose.dispose();
    }, [messageListData, loading]);
    React.useEffect(() => {
        const disposer = chatAgentService.onDidSendMessage((chunk) => {
            const relationId = aiReporter.start(reporter_1.AISerivceType.Agent, {
                msgType: reporter_1.AISerivceType.Agent,
                message: '',
            });
            const notifyMessage = createMessageByAI({
                id: (0, ide_core_common_1.uuid)(6),
                relationId,
                text: React.createElement(ChatReply_1.ChatNotify, { relationId: relationId, chunk: chunk }),
            }, styles.chat_notify);
            setMessageListData((msgList) => [...msgList, notifyMessage]);
            requestAnimationFrame(() => {
                scrollToBottom();
            });
        });
        return () => disposer.dispose();
    }, []);
    const handleAgentReply = React.useCallback(async (value) => {
        const { message, agentId, command } = value;
        const request = aiChatService.createRequest(message, agentId, command);
        if (!request) {
            return;
        }
        const startTime = Date.now();
        const relationId = aiReporter.start(reporter_1.AISerivceType.Agent, {
            msgType: reporter_1.AISerivceType.Agent,
            message: value.message,
        });
        const userMessage = createMessage({
            id: (0, ide_core_common_1.uuid)(6),
            relationId,
            position: 'right',
            title: ME_NAME,
            text: React.createElement(ChatEditor_1.CodeBlockWrapperInput, { text: message, agentId: agentId, relationId: relationId, command: command }),
            className: styles.chat_message_code,
            role: 'user',
        });
        const aiMessage = createMessageByAI({
            id: (0, ide_core_common_1.uuid)(6),
            relationId,
            className: styles.chat_with_more_actions,
            text: (React.createElement(ChatReply_1.ChatReply, { relationId: relationId, request: request, startTime: startTime, onRegenerate: () => {
                    msgStreamManager.sendThinkingStatue();
                    aiChatService.sendRequest(request, true);
                } })),
        });
        msgStreamManager.setCurrentSessionId(relationId);
        msgStreamManager.sendThinkingStatue();
        aiChatService.setLatestSessionId(relationId);
        aiChatService.sendRequest(request);
        setMessageListData((msgList) => [...msgList, userMessage, aiMessage]);
        if (containerRef && containerRef.current) {
            containerRef.current.scrollTop = Number.MAX_SAFE_INTEGER;
        }
    }, []);
    const handleSend = React.useCallback(async (value) => {
        const { message, prompt, reportType, agentId, command } = value;
        const preMessagelist = messageListData;
        if (agentId) {
            return handleAgentReply({ message, agentId, command });
        }
        setLoading(true);
        const userInput = await aiChatService.switchAIService(message, prompt);
        const startTime = +new Date();
        const relationId = aiReporter.start(reportType || userInput.type, {
            msgType: reportType || userInput.type,
            message: userInput.message,
        });
        const codeSendMessage = createMessage({
            id: (0, ide_core_common_1.uuid)(6),
            relationId,
            position: 'right',
            title: ME_NAME,
            text: React.createElement(ChatEditor_1.CodeBlockWrapperInput, { text: message, agentId: agentId, relationId: relationId, command: command }),
            className: styles.chat_message_code,
            role: 'user',
        });
        preMessagelist.push(codeSendMessage);
        setMessageListData(preMessagelist);
        updateState({});
        const replayCommandProps = {
            aiChatService,
            aiReporter,
            aiRunService,
            chatAgentService,
            relationId,
            startTime,
        };
        await handleReply(userInput, replayCommandProps);
    }, [messageListData, containerRef, loading]);
    React.useEffect(() => {
        const disposer = chatAgentService.onDidChangeAgents(async () => {
            const newDefaultAgentId = chatAgentService.getDefaultAgentId();
            setDefaultAgentId(newDefaultAgentId !== null && newDefaultAgentId !== void 0 ? newDefaultAgentId : '');
        });
        return () => disposer.dispose();
    }, []);
    const handleReply = React.useCallback(async (userInput, replayCommandProps) => {
        let aiMessage;
        if (userInput.type === reporter_1.AISerivceType.SearchDoc) {
            aiMessage = await AISearch(userInput.message, userInput.type, replayCommandProps);
        }
        else if (userInput.type === reporter_1.AISerivceType.SearchCode) {
            aiMessage = await AISearch(userInput.message, userInput.type, replayCommandProps);
        }
        else if (userInput.type === reporter_1.AISerivceType.Sumi) {
            aiMessage = await aiSumiService.searchCommand(userInput.message);
            aiMessage = await AIWithCommandReply(userInput.message, aiMessage, opener, replayCommandProps, async () => handleCommonRetry(userInput, replayCommandProps));
        }
        else if (userInput.type === reporter_1.AISerivceType.GPT ||
            userInput.type === reporter_1.AISerivceType.Explain ||
            userInput.type === reporter_1.AISerivceType.Optimize ||
            userInput.type === reporter_1.AISerivceType.Test) {
            aiMessage = await AIStreamReply(userInput.message, replayCommandProps);
        }
        else if (userInput.type === reporter_1.AISerivceType.Run) {
            aiMessage = await aiRunService.requestBackService(userInput.message, aiChatService.cancelIndicatorChatView.token);
            aiMessage = await AIChatRunReply(aiMessage, replayCommandProps);
        }
        if (aiMessage) {
            messageListData.push(aiMessage);
            setMessageListData([...messageListData]);
            updateState({});
            if (containerRef && containerRef.current) {
                containerRef.current.scrollTop = Number.MAX_SAFE_INTEGER;
            }
        }
        setLoading(false);
    }, [messageListData]);
    const handleCommonRetry = React.useCallback(async (userInput, replayCommandProps) => {
        setLoading(true);
        messageListData.pop();
        setMessageListData([...messageListData]);
        const startTime = +new Date();
        await handleReply(userInput, Object.assign(Object.assign({}, replayCommandProps), { startTime, isRetry: true }));
    }, [messageListData]);
    const handleClear = React.useCallback(() => {
        var _a;
        aiChatService.cancelChatViewToken();
        aiChatService.destroyStreamRequest(msgStreamManager.currentSessionId);
        aiChatService.clearSessionModel();
        // 清除滚动条出现时的分割线
        (_a = containerRef === null || containerRef === void 0 ? void 0 : containerRef.current) === null || _a === void 0 ? void 0 : _a.classList.remove(SCROLL_CLASSNAME);
        setMessageListData([firstMsg]);
    }, [messageListData]);
    const handleClose = React.useCallback(() => {
        commandService.executeCommand(command_1.AI_CHAT_PANEL_TOGGLE_VISIBLE.id);
    }, []);
    const handleThemeClick = (value) => {
        if (loading || loading2) {
            return;
        }
        setTheme(value);
    };
    return (React.createElement("div", { className: styles.ai_chat_view },
        React.createElement("div", { className: styles.header_container },
            React.createElement("div", { className: styles.left },
                React.createElement("span", { className: styles.title }, AI_NAME)),
            React.createElement("div", { className: styles.right },
                React.createElement(components_1.Popover, { insertClass: styles.popover_icon, id: 'ai-chat-header-clear', title: '\u6E05\u7A7A' },
                    React.createElement(ai_native_1.EnhanceIcon, { wrapperClassName: styles.action_btn, className: (0, ide_core_browser_1.getIcon)('clear'), onClick: handleClear })),
                React.createElement(components_1.Popover, { insertClass: styles.popover_icon, id: 'ai-chat-header-close', title: '\u5173\u95ED' },
                    React.createElement(ai_native_1.EnhanceIcon, { wrapperClassName: styles.action_btn, className: (0, ide_core_browser_1.getIcon)('window-close'), onClick: handleClose })))),
        React.createElement("div", { className: styles.body_container },
            React.createElement("div", { className: styles.left_bar, id: 'ai_chat_left_container' },
                React.createElement("div", { className: styles.chat_container, ref: containerRef },
                    React.createElement(react_chat_elements_1.MessageList, { className: styles.message_list, lockable: true, toBottomHeight: '100%', 
                        // @ts-ignore
                        dataSource: messageListData }),
                    loading && (React.createElement("div", { className: styles.chat_loading_msg_box },
                        React.createElement(react_chat_elements_1.SystemMessage, { title: AI_NAME, className: styles.smsg, 
                            // @ts-ignore
                            text: React.createElement(Thinking_1.Thinking, { status: 1 /* EMsgStreamStatus.THINKING */ }) })))),
                React.createElement("div", { className: styles.chat_input_wrap },
                    React.createElement("div", { className: styles.header_operate },
                        React.createElement("div", { className: styles.header_operate_left },
                            React.createElement(components_1.Popover, { id: 'ai-chat-header-explain', title: '\u89E3\u91CA\u4EE3\u7801' },
                                React.createElement("div", { className: styles.tag, onClick: () => handleThemeClick(common_1.InstructionEnum.aiExplainKey) }, "Explain")),
                            React.createElement(components_1.Popover, { id: 'ai-chat-header-test', title: '\u751F\u6210\u5355\u6D4B' },
                                React.createElement("div", { className: styles.tag, onClick: () => handleThemeClick(common_1.InstructionEnum.aiTestKey) }, "Test")),
                            React.createElement(components_1.Popover, { id: 'ai-chat-header-optimize', title: '\u4F18\u5316\u4EE3\u7801' },
                                React.createElement("div", { className: styles.tag, onClick: () => handleThemeClick(common_1.InstructionEnum.aiOptimzeKey) }, "Optimize"))),
                        React.createElement("div", { className: styles.header_operate_right })),
                    React.createElement(ChatInput_1.ChatInput, { onSend: (value, agentId, command) => handleSend({ message: value, agentId, command }), disabled: loading || loading2, enableOptions: true, theme: theme, setTheme: setTheme, agentId: agentId, setAgentId: setAgentId, defaultAgentId: defaultAgentId, command: command, setCommand: setCommand, ref: chatInputRef }))))));
});
// AI 回复组件，就是能一个字一个出现的那种效果
const AiReply = ({ text, endNode = React.createElement(React.Fragment, null), immediately = false }) => {
    const [currentIndex, setCurrentIndex] = React.useState(0);
    const [currentText, setCurrentText] = React.useState('');
    React.useEffect(() => {
        if (currentIndex < text.length) {
            if (immediately) {
                setCurrentText(text);
                setCurrentIndex(text.length);
            }
            else {
                const timeoutId = setTimeout(() => {
                    if (timeoutId) {
                        clearTimeout(timeoutId);
                    }
                    setCurrentText(text.slice(0, currentIndex + 1));
                    setCurrentIndex(currentIndex + 1);
                }, Math.floor(Math.random() * 41) + 10);
                return () => clearTimeout(timeoutId);
            }
        }
    }, [currentIndex, text]);
    return (React.createElement("div", { style: { whiteSpace: 'break-spaces' } }, currentIndex === text.length ? (React.createElement(React.Fragment, null,
        currentText,
        endNode)) : (currentText)));
};
const AISearch = async (input, type, params) => {
    try {
        const { aiChatService, relationId } = params;
        const uid = (0, ide_core_common_1.uuid)(6);
        const send = () => {
            aiChatService.setLatestSessionId(relationId);
            if (type === reporter_1.AISerivceType.SearchDoc) {
                aiChatService.searchDoc(input, relationId);
            }
            else {
                aiChatService.searchCode(input, relationId);
            }
        };
        send();
        const aiMessage = createMessageByAI({
            id: uid,
            relationId,
            text: (React.createElement(StreamMsg_1.StreamMsgWrapper, { sessionId: relationId, prompt: input, onRegenerate: () => send(), renderContent: (content) => (React.createElement("div", { className: styles.ai_chat_search_container },
                    React.createElement("div", { className: styles.ai_response_text },
                        React.createElement(ChatEditor_1.CodeBlockWrapper, { text: content, relationId: relationId, renderText: (text) => React.createElement(ChatMarkdown_1.ChatMarkdown, { content: text }) })))) })),
            className: styles.chat_with_more_actions,
        });
        return aiMessage;
    }
    catch (error) { }
};
// 流式输出渲染组件
const AIStreamReply = async (prompt, params) => {
    try {
        const { aiChatService, relationId } = params;
        const send = () => {
            aiChatService.setLatestSessionId(relationId);
            aiChatService.messageWithStream(prompt, {}, relationId);
        };
        send();
        const aiMessage = createMessageByAI({
            id: (0, ide_core_common_1.uuid)(6),
            relationId,
            text: (React.createElement(StreamMsg_1.StreamMsgWrapper, { sessionId: relationId, prompt: prompt, onRegenerate: () => send(), renderContent: (content) => React.createElement(Markdown_1.Markdown, { markdown: content, fillInIncompleteTokens: true, relationId: relationId }) })),
            className: styles.chat_with_more_actions,
        });
        return aiMessage;
    }
    catch (error) { }
};
// 带有代码的 AI 回复组件
const AICodeReply = (input, aiChatService, relationId) => {
    try {
        aiChatService.setLatestSessionId(relationId);
        const aiMessage = createMessageByAI({
            id: (0, ide_core_common_1.uuid)(6),
            relationId,
            text: (React.createElement(ChatMoreActions_1.ChatMoreActions, { sessionId: relationId },
                React.createElement(ChatEditor_1.CodeBlockWrapper, { text: input, relationId: relationId }))),
            className: styles.chat_with_more_actions,
        });
        return aiMessage;
    }
    catch (error) { }
};
// run 的 AI 回复组件
const AIChatRunReply = async (input, params) => {
    const { aiRunService, aiReporter, relationId, aiChatService, startTime } = params;
    let aiMessage;
    let success = true;
    try {
        const RenderAnswer = aiRunService.answerComponentRender();
        aiChatService.setLatestSessionId(relationId);
        aiMessage = createMessageByAI({
            id: (0, ide_core_common_1.uuid)(6),
            relationId,
            text: (React.createElement(ChatMoreActions_1.ChatMoreActions, { sessionId: relationId }, RenderAnswer ? (React.createElement(RenderAnswer, { input: input, relationId: relationId })) : (React.createElement(ChatEditor_1.CodeBlockWrapper, { text: input, relationId: relationId })))),
            className: styles.chat_with_more_actions,
        });
    }
    catch (error) {
        success = false;
    }
    aiReporter.end(relationId, {
        replytime: +new Date() - startTime,
        success,
        message: input,
    });
    return aiMessage;
};
// 带有命令按钮的 AI 回复
const AIWithCommandReply = async (userInput, commandRes, opener, params, onRetry) => {
    const { aiChatService, aiReporter, relationId, startTime, isRetry } = params;
    aiChatService.setLatestSessionId(relationId);
    const failedText = commandRes.errorCode
        ? common_1.AiResponseTips.ERROR_RESPONSE
        : !commandRes.data
            ? common_1.AiResponseTips.NOTFOUND_COMMAND
            : '';
    aiReporter.end(relationId, {
        replytime: +new Date() - startTime,
        success: !failedText,
        msgType: reporter_1.AISerivceType.Sumi,
        isRetry,
    });
    if (failedText) {
        return createMessageByAI({
            id: (0, ide_core_common_1.uuid)(6),
            relationId,
            text: (React.createElement(ChatMoreActions_1.ChatMoreActions, { sessionId: relationId, onRetry: onRetry }, failedText === common_1.AiResponseTips.NOTFOUND_COMMAND ? (React.createElement("div", null,
                React.createElement("p", null, failedText),
                React.createElement("p", null, common_1.AiResponseTips.NOTFOUND_COMMAND_TIP),
                React.createElement(components_1.Button, { style: { width: '100%' }, onClick: () => opener.open(ide_core_common_1.URI.from({
                        scheme: 'command',
                        path: ide_core_browser_1.QUICK_OPEN_COMMANDS.OPEN_WITH_COMMAND.id,
                        query: JSON.stringify([userInput]),
                    })) }, "\u6253\u5F00\u547D\u4EE4\u9762\u677F"))) : (failedText))),
        });
    }
    const { labelLocalized, label, delegate, id } = commandRes.data;
    function excuteCommand() {
        let success = true;
        try {
            opener.open(ide_core_common_1.URI.parse(`command:${delegate || id}`));
        }
        catch (_a) {
            success = false;
        }
        aiReporter.end(relationId, {
            replytime: +new Date() - startTime,
            success: true,
            msgType: reporter_1.AISerivceType.Sumi,
            message: id,
            useCommand: true,
            useCommandSuccess: success,
            isRetry,
        });
    }
    const aiMessage = createMessageByAI({
        id: (0, ide_core_common_1.uuid)(6),
        relationId,
        text: (React.createElement(ChatMoreActions_1.ChatMoreActions, { sessionId: relationId, onRetry: onRetry },
            React.createElement("div", { className: styles.chat_excute_result },
                React.createElement("div", null,
                    "\u5DF2\u5728\u7CFB\u7EDF\u5185\u627E\u5230\u9002\u5408\u529F\u80FD: ",
                    (labelLocalized === null || labelLocalized === void 0 ? void 0 : labelLocalized.localized) || label,
                    "\uFF0C\u53EF\u4EE5\u6309\u4EE5\u4E0B\u6B65\u9AA4\u5C1D\u8BD5\uFF1A"),
                React.createElement("ol", { className: styles.chat_result_list },
                    React.createElement("li", { style: { listStyle: 'inherit' } },
                        "\u6253\u5F00\u547D\u4EE4\u9762\u677F\uFF1A(",
                        ide_core_common_1.isMacintosh ? 'cmd' : 'ctrl',
                        " + shift + p)"),
                    React.createElement("li", { style: { listStyle: 'inherit' } },
                        "\u8F93\u5165\uFF1A",
                        (labelLocalized === null || labelLocalized === void 0 ? void 0 : labelLocalized.localized) || label)),
                React.createElement(components_1.Button, { className: styles.chat_excute_btn, onClick: excuteCommand }, "\u70B9\u51FB\u6267\u884C\u547D\u4EE4")))),
        className: styles.chat_with_more_actions,
    });
    return aiMessage;
};
//# sourceMappingURL=ai-chat.view.js.map