"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CodeBlockWrapperInput = exports.CodeBlockWrapper = exports.CodeEditorWithHighlight = void 0;
const tslib_1 = require("tslib");
const capitalize_1 = tslib_1.__importDefault(require("lodash/capitalize"));
const react_1 = tslib_1.__importStar(require("react"));
const react_highlight_1 = tslib_1.__importDefault(require("react-highlight"));
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const components_1 = require("@opensumi/ide-core-browser/lib/components");
const ai_native_1 = require("@opensumi/ide-core-browser/lib/components/ai-native");
const reporter_1 = require("@opensumi/ide-core-common/lib/ai-native/reporter");
const ide_editor_1 = require("@opensumi/ide-editor");
const editor_collection_service_1 = require("@opensumi/ide-editor/lib/browser/editor-collection.service");
const index_1 = require("@opensumi/ide-editor/lib/browser/index");
const command_service_1 = require("@opensumi/ide-editor/lib/browser/monaco-contrib/command/command.service");
const index_2 = require("../../common/index");
const styles = tslib_1.__importStar(require("./components.module.less"));
require("./highlightTheme.less");
const ChatEditor = ({ input, language }) => {
    const ref = react_1.default.useRef(null);
    const editorCollectionService = (0, ide_core_browser_1.useInjectable)(ide_editor_1.EditorCollectionService);
    const documentService = (0, ide_core_browser_1.useInjectable)(index_1.IEditorDocumentModelService);
    const clipboardService = (0, ide_core_browser_1.useInjectable)(ide_core_browser_1.IClipboardService);
    const monacoCommandRegistry = (0, ide_core_browser_1.useInjectable)(command_service_1.MonacoCommandRegistry);
    const languageService = (0, ide_core_browser_1.useInjectable)(index_1.ILanguageService);
    // 用于在复制代码的时候切换 popover 的标题
    const [isCoping, setIsCoping] = (0, react_1.useState)(false);
    const [codeEditor, setCodeEditor] = (0, react_1.useState)(null);
    // 这里暂时关闭
    // const textmateTokenizer = useInjectable<TextmateService>(TextmateService);
    const useUUID = (0, react_1.useMemo)(() => (0, ide_core_browser_1.uuid)(12), [ref, ref.current]);
    (0, react_1.useEffect)(() => {
        if (input && codeEditor) {
            codeEditor.monacoEditor.setValue(input);
        }
    }, [input, codeEditor]);
    const createEditor = async (container) => {
        var _a;
        const codeEditor = editorCollectionService.createCodeEditor(container, Object.assign(Object.assign({}, (0, ide_editor_1.getSimpleEditorOptions)()), { readOnly: true, lineNumbers: 'off', selectOnLineNumbers: true, scrollBeyondLastLine: false, lineDecorationsWidth: 8, dragAndDrop: false, padding: { top: 8, bottom: 8 }, mouseWheelZoom: false, scrollbar: {
                alwaysConsumeMouseWheel: false,
            }, wordWrap: 'off', ariaLabel: 'Code block', automaticLayout: true }));
        const docModel = await documentService.createModelReference(new ide_core_browser_1.URI(`ai/chat/editor/${useUUID}`).withScheme(ide_core_browser_1.Schemes.walkThroughSnippet));
        const model = docModel.instance.getMonacoModel();
        model.updateOptions({ tabSize: 2 });
        codeEditor.monacoEditor.setModel(model);
        if (language && languageService.getLanguage(language)) {
            (_a = codeEditor.monacoEditor.getModel()) === null || _a === void 0 ? void 0 : _a.setLanguage(language);
        }
        return codeEditor;
    };
    react_1.default.useEffect(() => {
        if (ref && ref.current) {
            createEditor(ref.current).then((codeEditor) => {
                if (codeEditor) {
                    codeEditor.monacoEditor.setValue(input);
                    requestAnimationFrame(() => {
                        ref.current.style.height = codeEditor.monacoEditor.getContentHeight() + 2 + 'px';
                    });
                    setCodeEditor(codeEditor);
                }
            });
        }
        return () => {
            if (codeEditor) {
                return codeEditor.dispose();
            }
        };
    }, [ref.current]);
    const handleCopy = (0, react_1.useCallback)(async () => {
        setIsCoping(true);
        await clipboardService.writeText(input);
        setTimeout(() => {
            setIsCoping(false);
        }, 1000);
    }, [clipboardService, input]);
    const handleInsert = (0, react_1.useCallback)(() => {
        const editor = monacoCommandRegistry.getActiveCodeEditor();
        if (editor) {
            const selection = editor.getSelection();
            if (selection) {
                (0, editor_collection_service_1.insertSnippetWithMonacoEditor)(editor, input, [selection], { undoStopBefore: false, undoStopAfter: false });
            }
        }
    }, [monacoCommandRegistry]);
    return (react_1.default.createElement("div", { className: styles.monaco_wrapper },
        react_1.default.createElement("div", { className: styles.action_toolbar },
            react_1.default.createElement(components_1.Popover, { id: `ai-chat-inser-${useUUID}`, title: '\u63D2\u5165\u4EE3\u7801' },
                react_1.default.createElement(ai_native_1.EnhanceIcon, { className: (0, ide_core_browser_1.getIcon)('insert'), onClick: () => handleInsert() })),
            react_1.default.createElement(components_1.Popover, { id: `ai-chat-copy-${useUUID}`, title: isCoping ? '复制成功' : '复制代码' },
                "\u00B7",
                react_1.default.createElement(ai_native_1.EnhanceIcon, { className: (0, ide_core_browser_1.getIcon)('copy'), onClick: () => handleCopy() }))),
        react_1.default.createElement("div", { ref: ref, className: styles.editor })));
};
const CodeEditorWithHighlight = ({ input, language, relationId }) => {
    const ref = react_1.default.useRef(null);
    const monacoCommandRegistry = (0, ide_core_browser_1.useInjectable)(command_service_1.MonacoCommandRegistry);
    const clipboardService = (0, ide_core_browser_1.useInjectable)(ide_core_browser_1.IClipboardService);
    const aiReporter = (0, ide_core_browser_1.useInjectable)(reporter_1.IAIReporter);
    const [isCoping, setIsCoping] = (0, react_1.useState)(false);
    const useUUID = (0, react_1.useMemo)(() => (0, ide_core_browser_1.uuid)(12), [ref, ref.current]);
    const handleCopy = (0, react_1.useCallback)(async () => {
        setIsCoping(true);
        await clipboardService.writeText(input);
        aiReporter.end(relationId, { copy: true });
        setTimeout(() => {
            setIsCoping(false);
        }, 1000);
    }, [clipboardService, input, relationId]);
    const handleInsert = (0, react_1.useCallback)(() => {
        const editor = monacoCommandRegistry.getActiveCodeEditor();
        if (editor) {
            const selection = editor.getSelection();
            if (selection) {
                (0, editor_collection_service_1.insertSnippetWithMonacoEditor)(editor, input, [selection], { undoStopBefore: false, undoStopAfter: false });
                aiReporter.end(relationId, { insert: true });
            }
        }
    }, [monacoCommandRegistry]);
    return (react_1.default.createElement("div", { className: styles.monaco_wrapper },
        react_1.default.createElement("div", { className: styles.action_toolbar },
            react_1.default.createElement(components_1.Popover, { id: `ai-chat-inser-${useUUID}`, title: '\u63D2\u5165\u4EE3\u7801' },
                react_1.default.createElement(ai_native_1.EnhanceIcon, { className: (0, ide_core_browser_1.getIcon)('insert'), onClick: () => handleInsert() })),
            react_1.default.createElement(components_1.Popover, { id: `ai-chat-copy-${useUUID}`, title: isCoping ? '复制成功' : '复制代码' },
                react_1.default.createElement(ai_native_1.EnhanceIcon, { className: (0, ide_core_browser_1.getIcon)('copy'), onClick: () => handleCopy() }))),
        react_1.default.createElement(react_highlight_1.default, { language: language, ref: ref, className: styles.editor }, input)));
};
exports.CodeEditorWithHighlight = CodeEditorWithHighlight;
const CodeBlock = ({ content = '', relationId, renderText, }) => {
    const rgInlineCode = /`([^`]+)`/g;
    const rgBlockCode = /```([^]+?)```/g;
    const rgBlockCodeBefore = /```([^]+)?/g;
    const renderCodeEditor = (content) => {
        const language = content.split('\n')[0].trim().toLowerCase();
        const heighLightLang = index_2.highLightLanguageSupport.find((lang) => lang === language) || 'plaintext';
        content = content.replace(/.*?\n/, '');
        content = content.trim();
        return (react_1.default.createElement("div", { className: styles.code_block },
            react_1.default.createElement("div", { className: styles.code_language }, (0, capitalize_1.default)(heighLightLang)),
            react_1.default.createElement(exports.CodeEditorWithHighlight, { input: content, language: language, relationId: relationId })));
    };
    const render = (0, react_1.useMemo)(() => {
        const blocks = content.split(rgBlockCode);
        const renderedContent = [];
        blocks.map((block, index) => {
            if (index % 2 === 0) {
                block.split(rgInlineCode).map((text, index) => {
                    if (index % 2 === 0) {
                        if (text.includes('```')) {
                            const cutchunk = text.split(rgBlockCodeBefore).filter(Boolean);
                            if (cutchunk.length === 2) {
                                renderedContent.push(cutchunk[0]);
                                renderedContent.push(renderCodeEditor(cutchunk[1]));
                                return;
                            }
                        }
                        if (renderText) {
                            renderedContent.push(renderText(text));
                        }
                        else {
                            renderedContent.push(text);
                        }
                    }
                    else {
                        renderedContent.push(react_1.default.createElement("span", { className: styles.code_inline, key: index }, text));
                    }
                });
            }
            else {
                renderedContent.push(renderCodeEditor(block));
            }
        });
        return renderedContent;
    }, [content, renderText]);
    return react_1.default.createElement(react_1.default.Fragment, null, render);
};
const CodeBlockWrapper = ({ text, renderText, relationId, }) => (react_1.default.createElement("div", { className: styles.ai_chat_code_wrapper },
    react_1.default.createElement("div", { className: styles.render_text },
        react_1.default.createElement(CodeBlock, { content: text, renderText: renderText, relationId: relationId }))));
exports.CodeBlockWrapper = CodeBlockWrapper;
const CodeBlockWrapperInput = ({ text, relationId, agentId, command, }) => {
    const [tag, setTag] = (0, react_1.useState)('');
    const [txt, setTxt] = (0, react_1.useState)(text);
    react_1.default.useEffect(() => {
        Object.values(index_2.InstructionEnum).find((str) => {
            if (txt.startsWith(str)) {
                setTag(str);
                setTxt(txt.slice(str.length));
                return;
            }
        });
    }, [text]);
    return (react_1.default.createElement("div", { className: styles.ai_chat_code_wrapper },
        react_1.default.createElement("div", { className: styles.render_text },
            tag && (react_1.default.createElement("div", { className: styles.tag_wrapper },
                react_1.default.createElement("span", { className: styles.tag }, tag))),
            agentId && (react_1.default.createElement("div", { className: styles.tag, style: { marginRight: 4 } },
                "@",
                agentId)),
            command && react_1.default.createElement("div", { className: styles.tag },
                "/ ",
                command),
            react_1.default.createElement(CodeBlock, { content: txt, relationId: relationId }))));
};
exports.CodeBlockWrapperInput = CodeBlockWrapperInput;
//# sourceMappingURL=ChatEditor.js.map